"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Notifications = void 0;
const tslib_1 = require("tslib");
class Notifications {
    constructor(client) {
        this.client = client;
    }
    getNotification(parameters, callback) {
        return (0, tslib_1.__awaiter)(this, void 0, void 0, function* () {
            const config = {
                url: `/notifications/${parameters.id}`,
                method: 'GET',
                params: {
                    board: parameters.board,
                    board_fields: parameters.boardFields,
                    card: parameters.card,
                    card_fields: parameters.cardFields,
                    display: parameters.display,
                    entities: parameters.entities,
                    fields: parameters.fields,
                    list: parameters.list,
                    member: parameters.member,
                    member_fields: parameters.memberFields,
                    memberCreator: parameters.memberCreator,
                    memberCreator_fields: parameters.memberCreatorFields,
                    organization: parameters.organization,
                    organization_fields: parameters.organizationFields,
                },
            };
            return this.client.sendRequest(config, callback);
        });
    }
    updateNotification(parameters, callback) {
        return (0, tslib_1.__awaiter)(this, void 0, void 0, function* () {
            const config = {
                url: `/notifications/${parameters.id}`,
                method: 'PUT',
                params: {
                    unread: parameters.unread,
                },
            };
            return this.client.sendRequest(config, callback);
        });
    }
    getNotificationField(parameters, callback) {
        return (0, tslib_1.__awaiter)(this, void 0, void 0, function* () {
            const config = {
                url: `/notifications/${parameters.id}/${parameters.field}`,
                method: 'GET',
            };
            return this.client.sendRequest(config, callback);
        });
    }
    markAllNotificationsAsRead(parameters, callback) {
        return (0, tslib_1.__awaiter)(this, void 0, void 0, function* () {
            const config = {
                url: '/notifications/all/read',
                method: 'POST',
                params: {
                    read: parameters === null || parameters === void 0 ? void 0 : parameters.read,
                    ids: parameters === null || parameters === void 0 ? void 0 : parameters.ids,
                },
            };
            return this.client.sendRequest(config, callback);
        });
    }
    updateNotificationReadStatus(parameters, callback) {
        return (0, tslib_1.__awaiter)(this, void 0, void 0, function* () {
            const config = {
                url: `/notifications/${parameters.id}/unread`,
                method: 'PUT',
                params: {
                    value: parameters.value,
                },
            };
            return this.client.sendRequest(config, callback);
        });
    }
    getNotificationBoard(parameters, callback) {
        return (0, tslib_1.__awaiter)(this, void 0, void 0, function* () {
            const config = {
                url: `/notifications/${parameters.id}/board`,
                method: 'GET',
                params: {
                    fields: parameters.fields,
                },
            };
            return this.client.sendRequest(config, callback);
        });
    }
    getNotificationCard(parameters, callback) {
        return (0, tslib_1.__awaiter)(this, void 0, void 0, function* () {
            const config = {
                url: `/notifications/${parameters.id}/card`,
                method: 'GET',
                params: {
                    fields: parameters.fields,
                },
            };
            return this.client.sendRequest(config, callback);
        });
    }
    getNotificationList(parameters, callback) {
        return (0, tslib_1.__awaiter)(this, void 0, void 0, function* () {
            const config = {
                url: `/notifications/${parameters.id}/list`,
                method: 'GET',
                params: {
                    fields: parameters.fields,
                },
            };
            return this.client.sendRequest(config, callback);
        });
    }
    getNotificationMember(parameters, callback) {
        return (0, tslib_1.__awaiter)(this, void 0, void 0, function* () {
            const config = {
                url: `/notifications/${parameters.id}/member`,
                method: 'GET',
                params: {
                    fields: parameters.fields,
                },
            };
            return this.client.sendRequest(config, callback);
        });
    }
    getNotificationMemberCreator(parameters, callback) {
        return (0, tslib_1.__awaiter)(this, void 0, void 0, function* () {
            const config = {
                url: `/notifications/${parameters.id}/memberCreator`,
                method: 'GET',
                params: {
                    fields: parameters.fields,
                },
            };
            return this.client.sendRequest(config, callback);
        });
    }
    getNotificationOrganization(parameters, callback) {
        return (0, tslib_1.__awaiter)(this, void 0, void 0, function* () {
            const config = {
                url: `/notifications/${parameters.id}/organization`,
                method: 'GET',
                params: {
                    fields: parameters.fields,
                },
            };
            return this.client.sendRequest(config, callback);
        });
    }
}
exports.Notifications = Notifications;
