"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Organizations = void 0;
const tslib_1 = require("tslib");
class Organizations {
    constructor(client) {
        this.client = client;
    }
    createOrganization(parameters, callback) {
        return (0, tslib_1.__awaiter)(this, void 0, void 0, function* () {
            const config = {
                url: '/organizations',
                method: 'POST',
                params: {
                    displayName: parameters.displayName,
                    desc: parameters.desc,
                    name: parameters.name,
                    website: parameters.website,
                },
            };
            return this.client.sendRequest(config, callback);
        });
    }
    getOrganization(parameters, callback) {
        return (0, tslib_1.__awaiter)(this, void 0, void 0, function* () {
            const config = {
                url: `/organizations/${parameters.id}`,
                method: 'GET',
            };
            return this.client.sendRequest(config, callback);
        });
    }
    updateOrganization(parameters, callback) {
        return (0, tslib_1.__awaiter)(this, void 0, void 0, function* () {
            const config = {
                url: `/organizations/${parameters.id}`,
                method: 'PUT',
                params: {
                    name: parameters.name,
                    displayName: parameters.displayName,
                    desc: parameters.desc,
                    website: parameters.website,
                    'prefs/associatedDomain': parameters.associatedDomain,
                    'prefs/externalMembersDisabled': parameters.externalMembersDisabled,
                    'prefs/googleAppsVersion': parameters.googleAppsVersion,
                    'prefs/boardVisibilityRestrict/org': parameters.org,
                    'prefs/boardVisibilityRestrict/private': parameters.private,
                    'prefs/boardVisibilityRestrict/public': parameters.public,
                    'prefs/orgInviteRestrict': parameters.orgInviteRestrict,
                    'prefs/permissionLevel': parameters.permissionLevel,
                },
            };
            return this.client.sendRequest(config, callback);
        });
    }
    deleteOrganization(parameters, callback) {
        return (0, tslib_1.__awaiter)(this, void 0, void 0, function* () {
            const config = {
                url: `/organizations/${parameters.id}`,
                method: 'DELETE',
            };
            return this.client.sendRequest(config, callback);
        });
    }
    getOrganizationField(parameters, callback) {
        return (0, tslib_1.__awaiter)(this, void 0, void 0, function* () {
            const config = {
                url: `/organizations/${parameters.id}/${parameters.field}`,
                method: 'GET',
            };
            return this.client.sendRequest(config, callback);
        });
    }
    getOrganizationActions(parameters, callback) {
        return (0, tslib_1.__awaiter)(this, void 0, void 0, function* () {
            const config = {
                url: `/organizations/${parameters.id}/actions`,
                method: 'GET',
            };
            return this.client.sendRequest(config, callback);
        });
    }
    getOrganizationBoards(parameters, callback) {
        return (0, tslib_1.__awaiter)(this, void 0, void 0, function* () {
            const config = {
                url: `/organizations/${parameters.id}/boards`,
                method: 'GET',
                params: {
                    filter: parameters.filter,
                    fields: parameters.fields,
                },
            };
            return this.client.sendRequest(config, callback);
        });
    }
    getOrganizationExports(parameters, callback) {
        return (0, tslib_1.__awaiter)(this, void 0, void 0, function* () {
            const config = {
                url: `/organizations/${parameters.id}/exports`,
                method: 'GET',
            };
            return this.client.sendRequest(config, callback);
        });
    }
    exportOrganizationCSV(parameters, callback) {
        return (0, tslib_1.__awaiter)(this, void 0, void 0, function* () {
            const config = {
                url: `/organizations/${parameters.id}/exports`,
                method: 'POST',
                params: {
                    attachments: parameters.attachments,
                },
            };
            return this.client.sendRequest(config, callback);
        });
    }
    getOrganizationMembers(parameters, callback) {
        return (0, tslib_1.__awaiter)(this, void 0, void 0, function* () {
            const config = {
                url: `/organizations/${parameters.id}/members`,
                method: 'GET',
            };
            return this.client.sendRequest(config, callback);
        });
    }
    updateOrganizationMember(parameters, callback) {
        return (0, tslib_1.__awaiter)(this, void 0, void 0, function* () {
            const config = {
                url: `/organizations/${parameters.id}/members`,
                method: 'PUT',
                params: {
                    email: parameters.email,
                    fullName: parameters.fullName,
                    type: parameters.type,
                },
            };
            return this.client.sendRequest(config, callback);
        });
    }
    getOrganizationMemberships(parameters, callback) {
        return (0, tslib_1.__awaiter)(this, void 0, void 0, function* () {
            const config = {
                url: `/organizations/${parameters.id}/memberships`,
                method: 'GET',
                params: {
                    filter: parameters.filter,
                    member: parameters.member,
                },
            };
            return this.client.sendRequest(config, callback);
        });
    }
    getOrganizationMembership(parameters, callback) {
        return (0, tslib_1.__awaiter)(this, void 0, void 0, function* () {
            const config = {
                url: `/organizations/${parameters.id}/memberships/${parameters.idMembership}`,
                method: 'GET',
                params: {
                    member: parameters.member,
                },
            };
            return this.client.sendRequest(config, callback);
        });
    }
    getOrganizationPluginData(parameters, callback) {
        return (0, tslib_1.__awaiter)(this, void 0, void 0, function* () {
            const config = {
                url: `/organizations/${parameters.id}/pluginData`,
                method: 'GET',
            };
            return this.client.sendRequest(config, callback);
        });
    }
    getOrganizationTags(parameters, callback) {
        return (0, tslib_1.__awaiter)(this, void 0, void 0, function* () {
            const config = {
                url: `/organizations/${parameters.id}/tags`,
                method: 'GET',
            };
            return this.client.sendRequest(config, callback);
        });
    }
    createOrganizationTag(parameters, callback) {
        return (0, tslib_1.__awaiter)(this, void 0, void 0, function* () {
            const config = {
                url: `/organizations/${parameters.id}/tags`,
                method: 'POST',
            };
            return this.client.sendRequest(config, callback);
        });
    }
    addOrganizationMember(parameters, callback) {
        return (0, tslib_1.__awaiter)(this, void 0, void 0, function* () {
            const config = {
                url: `/organizations/${parameters.id}/members/${parameters.idMember}`,
                method: 'PUT',
                params: {
                    type: parameters.type,
                },
            };
            return this.client.sendRequest(config, callback);
        });
    }
    deleteOrganizationMember(parameters, callback) {
        return (0, tslib_1.__awaiter)(this, void 0, void 0, function* () {
            const config = {
                url: `/organizations/${parameters.id}/members/${parameters.idMember}`,
                method: 'DELETE',
            };
            return this.client.sendRequest(config, callback);
        });
    }
    updateOrganizationDeactivateStatus(parameters, callback) {
        return (0, tslib_1.__awaiter)(this, void 0, void 0, function* () {
            const config = {
                url: `/organizations/${parameters.id}/members/${parameters.idMember}/deactivated`,
                method: 'PUT',
                params: {
                    value: parameters.value,
                },
            };
            return this.client.sendRequest(config, callback);
        });
    }
    /** Set the logo image for a Workspace */
    setOrganizationLogo(parameters, callback) {
        return (0, tslib_1.__awaiter)(this, void 0, void 0, function* () {
            const config = {
                url: `/organizations/${parameters.id}/logo`,
                method: 'POST',
                params: {
                    file: parameters.file,
                },
            };
            return this.client.sendRequest(config, callback);
        });
    }
    deleteOrganizationLogo(parameters, callback) {
        return (0, tslib_1.__awaiter)(this, void 0, void 0, function* () {
            const config = {
                url: `/organizations/${parameters.id}/logo`,
                method: 'DELETE',
            };
            return this.client.sendRequest(config, callback);
        });
    }
    deleteOrganizationMemberFromAll(parameters, callback) {
        return (0, tslib_1.__awaiter)(this, void 0, void 0, function* () {
            const config = {
                url: `/organizations/${parameters.id}/members/${parameters.idMember}/all`,
                method: 'DELETE',
            };
            return this.client.sendRequest(config, callback);
        });
    }
    deleteOrganizationAssociatedDomain(parameters, callback) {
        return (0, tslib_1.__awaiter)(this, void 0, void 0, function* () {
            const config = {
                url: `/organizations/${parameters.id}/prefs/associatedDomain`,
                method: 'DELETE',
            };
            return this.client.sendRequest(config, callback);
        });
    }
    deleteOrganizationInvites(parameters, callback) {
        return (0, tslib_1.__awaiter)(this, void 0, void 0, function* () {
            const config = {
                url: `/organizations/${parameters.id}/prefs/orgInviteRestrict`,
                method: 'DELETE',
            };
            return this.client.sendRequest(config, callback);
        });
    }
    deleteOrganizationTag(parameters, callback) {
        return (0, tslib_1.__awaiter)(this, void 0, void 0, function* () {
            const config = {
                url: `/organizations/${parameters.id}/tags/${parameters.idTag}`,
                method: 'DELETE',
            };
            return this.client.sendRequest(config, callback);
        });
    }
    getOrganizationNewBillableGuestBoard(parameters, callback) {
        return (0, tslib_1.__awaiter)(this, void 0, void 0, function* () {
            const config = {
                url: `/organizations/${parameters.id}/newBillableGuests/${parameters.idBoard}`,
                method: 'GET',
            };
            return this.client.sendRequest(config, callback);
        });
    }
}
exports.Organizations = Organizations;
